# Welcome to cgul's documentation!

cgul is a python package which can be used to ensure consistent data format when working with Xarray type data objects. It is a lightweight package that works on an xarray-in/xarray-out basis, and is intended for use with other geo-data packages.

# Getting Started

- [Overview](../getting_started/overview)
- [Installing](../getting_started/installing)
- [Usage](../getting_started/usage)

```{toctree}
:caption: 'Getting Started:'
:maxdepth: 1

  getting_started/overview.md
  getting_started/installing.md
  getting_started/usage.md
```

```{toctree}
:caption: 'Contents:'
:maxdepth: 2
```

## License

*cgul* is available under the open source [Apache License](http://www.apache.org/licenses/LICENSE-2.0.html)

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
